function list = alignsegments(list, stride);

%ALIGNSEGMENTS Align segments with frame file boundaries
%
% ALIGNSEGMENTS Aligns the given segment list on boundaries corresponding
% to frame files of the specified length.  The resulting segments list is
% useful for determining the timestamps of frame files included in each
% segment.  The resulting segment list is returned.
%
%SYNOPSIS
%   OUT = alignsegments(IN, STRIDE);
%
%INPUTS
%   IN        input segment list
%   STRIDE    (optional) number of seconds per frame file
%     If no stride is specified, a default value of 16 seconds is assumed.
%
%OUTPUT
%   OUT       output segment list
%
% The segments list should be provided in the form of an N-by-2 matrix,
% formed from adjacent column-wise vectors of segment start and stop
% times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half-closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
% This same definition is extended to the output segments, which are
% aligned on frame file boundaries.  The range of frame file timestamps
% containing valid data from the original segment is given by the vector
% start : stride : stop - stride.
%
% As an alternative, each segment may also be specified by its start time
% and duration.  However, the resulting segment list will be returned in
% terms of start and stop times.
%
% ALIGNSEGMENTS also uses CULLSEGMENTS and MERGESEGMENTS to remove zero
% length segments and merge any overlapping or adjacent segments.
%
% See also PADSEGMENTS and CULLSEGMENTS.
%
%AUTHOR
%   Shourov K. Chatterji (No longer part of the LV Collaboration.)

% $Id: alignsegments.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% parse command line arguments
error(nargchk(1, 2, nargin));

% default stride
if nargin == 1,
  stride = 16;
end

% standardize segment list
list = stdsegments(list);

% handle empty lists
if isempty(list),
  return;
end

% remove zero length segments
list = cullsegments(list);

% merge overlapping or adjacent segments
list = mergesegments(list);

% extract start and stop vectors
start = list(:,1);
stop = list(:,2);

% align segments on frame file boundaries
start = stride * floor(start / stride);
stop = stride * ceil(stop / stride);

% create return segment list
list = [start stop];

% merge overlapping or adjacent segments
list = mergesegments(list);

% return to calling function
return;
