function duration = lensegments(list);

%LENSEGMENTS Determine duration of segments in a segment list
%
% LENSEGMENTS reads the requested segment list and determines the
% duration of each segment.  The resulting vector of segment durations
% is returned.
%
%SYNOPSIS
%   DURATION = lensegments(LIST);
%
%INPUT
%   LIST         input segment list
%
%OUTPUT
%   DURATION     vector of segment durations
%
% The segments list should be provided in the form of an N-by-2 matrix,
% formed from adjacent column-wise vectors of segment start and stop
% times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
% As an alternative, each segment may also be specified by its start time
% and duration.  However, the resulting segment list will be returned in
% terms of start and stop times.
%
% See also NUMSEGMENTS, SORTSEGMENTS, LOADSEGMENTS, and WRITESEGMENTS.
%
%AUTHOR
%   Shourov K. Chatterji (No longer part of the LV Collaboration)

% $Id: lensegments.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% parse command line arguments
error(nargchk(1, 1, nargin));

% standardize segment list
list = stdsegments(list);

% handle empty lists
if isempty(list),
  duration = [];
  return;
end

% extract start and stop vectors
start = list(:, 1);
stop = list(:, 2);

% get segment durations
duration = stop - start;

% return to calling function
return;
