function list = loadconlog(file)

%LOADCONLOG Read data segments from conlog output file
%
% LOADCONLOG Reads the specified conlog file and extracts the listed data
% segments.
%
%SYNOPSIS
%   LIST = loadconlog(FILE)
%
%INPUT
%   FILE   conlog file name
%
%OUTPUT
%   LIST   segment list
%
% The resulting segments list is provided in the form of an N-by-2 matrix,
% formed from adjacent column-wise vectors of segment start and stop times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
%AUTHOR
%   Shourov K. Chatterji (No longer part of the LV Collaboration)

% $Id: loadconlog.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% parse command line arguments
error(nargchk(1, 1, nargin));

% open file
[fid, fmessage] = fopen(file, 'r');
if fid == -1,
  error(fmessage);
end

% skip to end of header
while 1,
  string = fgetl(fid);
  if ~ischar(string),
    error([file ' is not a conlog file']);
  end
  if string(1) == '-',
    break;
  end
end

% read segments
list = [];
while 1,
  string = fgetl(fid);
  if ~ischar(string),
    error([file ' is not a conlog file']);
  end
  if length(string) == 0,
    break;
  end
  segment = sscanf(string, '%*s %*d %*s %d %*s %d', [1 2]);
  list = [list; segment;];
end

% close file
fclose(fid);

% standardize segment list
list = stdsegments(list);

% remove zero length segments
list = cullsegments(list);

% merge overlapping or adjacent segments
list = mergesegments(list);

% return to calling function
return;
